# coding=utf-8

from django.utils import timezone
from django.db import transaction
from django.db.models import F
from django.conf import settings
from rest_framework import generics, mixins
from rest_framework.views import APIView
from rest_framework.viewsets import GenericViewSet
from rest_framework.decorators import action
from rest_framework.exceptions import NotFound

from utils import response_ok
from utils.permission import IsCustomerUser
from utils.exceptions import CustomError
from .serializers import SeriesSerializer
from apps.activity.models import Activity
from apps.vehicle.filters import SeriesFilter
from apps.vehicle.models import Series


class SeriesListViewSet(generics.ListAPIView):
    queryset = Series.objects.filter(enabled=True, delete=False, is_hot=True)
    serializer_class = SeriesSerializer

    def filter_queryset(self, queryset):
        f = SeriesFilter(self.request.GET, queryset=queryset)
        return f.qs

    def list(self, request, *args, **kwargs):
        queryset = self.filter_queryset(self.get_queryset())
        serializer = self.get_serializer(queryset, many=True)
        return response_ok(serializer.data)

